@@ -71,8 +71,6 @@ file_open_image (Gimp                *gimp,
                  GimpContext         *context,
                  GimpProgress        *progress,
                  GFile               *file,
-                 gint                 vector_width,
-                 gint                 vector_height,
                  gboolean             as_new,
                  GimpPlugInProcedure *file_proc,
                  GimpRunMode          run_mode,
@@ -119,7 +117,8 @@ file_open_image (Gimp                *gimp,
     }
 
   /* FIXME enable these tests for remote files again, needs testing */
-  if (g_file_is_native (file))
+  if (g_file_is_native (file) &&
+      g_file_query_exists (file, NULL))
     {
       GFileInfo *info;
 
@@ -128,35 +127,27 @@ file_open_image (Gimp                *gimp,
                                 G_FILE_ATTRIBUTE_ACCESS_CAN_READ,
                                 G_FILE_QUERY_INFO_NONE,
                                 NULL, error);
+      if (! info)
+        return NULL;
 
-      if (info != NULL)
+      if (g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_STANDARD_TYPE) != G_FILE_TYPE_REGULAR)
         {
-          if (g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_STANDARD_TYPE) != G_FILE_TYPE_REGULAR)
-            {
-              g_set_error_literal (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                                   _("Not a regular file"));
-              g_object_unref (info);
-              return NULL;
-            }
-
-          if (! g_file_info_get_attribute_boolean (info,
-                                                   G_FILE_ATTRIBUTE_ACCESS_CAN_READ))
-            {
-              g_set_error_literal (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                                   _("Permission denied"));
-              g_object_unref (info);
-              return NULL;
-            }
-
+          g_set_error_literal (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
+                               _("Not a regular file"));
           g_object_unref (info);
-        }
-      else
-        {
-          /* File likely does not exists. error will already have a more
-           * accurate reason.
-           */
           return NULL;
         }
+
+      if (! g_file_info_get_attribute_boolean (info,
+                                               G_FILE_ATTRIBUTE_ACCESS_CAN_READ))
+        {
+          g_set_error_literal (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
+                               _("Permission denied"));
+          g_object_unref (info);
+          return NULL;
+        }
+
+      g_object_unref (info);
     }
 
   if (! file_proc)
@@ -213,30 +204,13 @@ file_open_image (Gimp                *gimp,
   if (progress)
     g_object_add_weak_pointer (G_OBJECT (progress), (gpointer) &progress);
 
-  if (file_proc->handles_vector)
-    {
-      return_vals =
-        gimp_pdb_execute_procedure_by_name (gimp->pdb,
-                                            context, progress, error,
-                                            gimp_object_get_name (file_proc),
-                                            GIMP_TYPE_RUN_MODE, run_mode,
-                                            G_TYPE_FILE,        file,
-                                            G_TYPE_INT,         vector_width,
-                                            G_TYPE_INT,         vector_height,
-                                            G_TYPE_BOOLEAN,     TRUE,
-                                            G_TYPE_BOOLEAN,     vector_width && vector_height ? FALSE : TRUE,
-                                            G_TYPE_NONE);
-    }
-  else
-    {
-      return_vals =
-        gimp_pdb_execute_procedure_by_name (gimp->pdb,
-                                            context, progress, error,
-                                            gimp_object_get_name (file_proc),
-                                            GIMP_TYPE_RUN_MODE, run_mode,
-                                            G_TYPE_FILE,        file,
-                                            G_TYPE_NONE);
-    }
+  return_vals =
+    gimp_pdb_execute_procedure_by_name (gimp->pdb,
+                                        context, progress, error,
+                                        gimp_object_get_name (file_proc),
+                                        GIMP_TYPE_RUN_MODE, run_mode,
+                                        G_TYPE_FILE,        file,
+                                        G_TYPE_NONE);
 
   if (progress)
     g_object_remove_weak_pointer (G_OBJECT (progress), (gpointer) &progress);
@@ -530,7 +504,7 @@ file_open_with_proc_and_display (Gimp                *gimp,
     run_mode = GIMP_RUN_NONINTERACTIVE;
 
   image = file_open_image (gimp, context, progress,
-                           file, 0, 0,
+                           file,
                            as_new,
                            file_proc,
                            run_mode,
@@ -566,7 +540,7 @@ file_open_with_proc_and_display (Gimp                *gimp,
           g_free (basename);
         }
 
-      if (gimp_create_display (image->gimp, image, gimp_unit_pixel (), 1.0,
+      if (gimp_create_display (image->gimp, image, GIMP_UNIT_PIXEL, 1.0,
                                monitor))
         {
           /*  the display owns the image now  */
@@ -630,10 +604,7 @@ file_open_layers (Gimp                *gimp,
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
   new_image = file_open_image (gimp, context, progress,
-                               file,
-                               gimp_image_get_width (dest_image),
-                               gimp_image_get_height (dest_image),
-                               FALSE,
+                               file, FALSE,
                                file_proc,
                                run_mode,
                                status, &mime_type, error);
@@ -747,11 +718,6 @@ static void
 file_open_sanitize_image (GimpImage *image,
                           gboolean   as_new)
 {
-  /* This should never occur, but apparently it does sometimes #13702
-   * Avoids infinite loop in the while statement below.
-   */
-  g_return_if_fail (GIMP_IS_IMAGE (image));
-
   if (as_new)
     gimp_image_set_file (image, NULL);
 
