@@ -35,7 +35,6 @@
 #include "widgets-types.h"
 
 #include "config/gimpcoreconfig.h"
-#include "config/gimpguiconfig.h"
 
 #include "gegl/gimp-gegl-loops.h"
 
@@ -64,10 +63,8 @@ enum
 
 struct _GimpViewRendererPrivate
 {
-  GimpViewBorderType  border_type;
-  GeglColor          *border_color;
-
   cairo_pattern_t    *pattern;
+  cairo_surface_t    *icon_surface;
   gchar              *bg_icon_name;
 
   GimpColorConfig    *color_config;
@@ -117,10 +114,6 @@ static cairo_pattern_t *
                  gimp_view_renderer_create_background (GimpViewRenderer   *renderer,
                                                        GtkWidget          *widget);
 
-static void      gimp_view_renderer_redraw            (GimpGuiConfig      *config,
-                                                       const GParamSpec   *pspec,
-                                                       GimpViewRenderer   *renderer);
-
 
 G_DEFINE_TYPE_WITH_PRIVATE (GimpViewRenderer, gimp_view_renderer, G_TYPE_OBJECT)
 
@@ -128,6 +121,11 @@ G_DEFINE_TYPE_WITH_PRIVATE (GimpViewRenderer, gimp_view_renderer, G_TYPE_OBJECT)
 
 static guint renderer_signals[LAST_SIGNAL] = { 0 };
 
+static GimpRGB  black_color;
+static GimpRGB  white_color;
+static GimpRGB  green_color;
+static GimpRGB  red_color;
+
 
 static void
 gimp_view_renderer_class_init (GimpViewRendererClass *klass)
@@ -145,8 +143,11 @@ gimp_view_renderer_class_init (GimpViewRendererClass *klass)
   object_class->dispose  = gimp_view_renderer_dispose;
   object_class->finalize = gimp_view_renderer_finalize;
 
-  klass->default_bg      = GIMP_VIEW_BG_STYLE;
-  klass->follow_theme_bg = GIMP_VIEW_BG_STYLE;
+  klass->update          = NULL;
+  klass->set_context     = gimp_view_renderer_real_set_context;
+  klass->invalidate      = gimp_view_renderer_real_invalidate;
+  klass->draw            = gimp_view_renderer_real_draw;
+  klass->render          = gimp_view_renderer_real_render;
 
   klass->frame           = NULL;
   klass->frame_left      = 0;
@@ -154,11 +155,10 @@ gimp_view_renderer_class_init (GimpViewRendererClass *klass)
   klass->frame_top       = 0;
   klass->frame_bottom    = 0;
 
-  klass->update          = NULL;
-  klass->set_context     = gimp_view_renderer_real_set_context;
-  klass->invalidate      = gimp_view_renderer_real_invalidate;
-  klass->draw            = gimp_view_renderer_real_draw;
-  klass->render          = gimp_view_renderer_real_render;
+  gimp_rgba_set (&black_color, 0.0, 0.0, 0.0, GIMP_OPACITY_OPAQUE);
+  gimp_rgba_set (&white_color, 1.0, 1.0, 1.0, GIMP_OPACITY_OPAQUE);
+  gimp_rgba_set (&green_color, 0.0, 0.94, 0.0, GIMP_OPACITY_OPAQUE);
+  gimp_rgba_set (&red_color,   1.0, 0.0, 0.0, GIMP_OPACITY_OPAQUE);
 }
 
 static void
@@ -166,11 +166,15 @@ gimp_view_renderer_init (GimpViewRenderer *renderer)
 {
   renderer->priv = gimp_view_renderer_get_instance_private (renderer);
 
-  renderer->dot_for_dot = TRUE;
-  renderer->surface_bg  = GIMP_VIEW_BG_STYLE;
-  renderer->size        = -1;
+  renderer->viewable = NULL;
+
+  renderer->dot_for_dot  = TRUE;
+
+  renderer->border_type  = GIMP_VIEW_BORDER_BLACK;
+  renderer->border_color = black_color;
+
+  renderer->size         = -1;
 
-  renderer->priv->border_type  = GIMP_VIEW_BORDER_STYLE_FG;
   renderer->priv->needs_render = TRUE;
 }
 
@@ -185,8 +189,6 @@ gimp_view_renderer_dispose (GObject *object)
   if (renderer->context)
     gimp_view_renderer_set_context (renderer, NULL);
 
-  g_clear_object (&renderer->priv->border_color);
-
   if (renderer->priv->color_config)
     gimp_view_renderer_set_color_config (renderer, NULL);
 
@@ -200,10 +202,10 @@ gimp_view_renderer_finalize (GObject *object)
 {
   GimpViewRenderer *renderer = GIMP_VIEW_RENDERER (object);
 
-  g_clear_pointer (&renderer->surface, cairo_surface_destroy);
   g_clear_pointer (&renderer->priv->pattern, cairo_pattern_destroy);
+  g_clear_pointer (&renderer->surface, cairo_surface_destroy);
+  g_clear_pointer (&renderer->priv->icon_surface, cairo_surface_destroy);
   g_clear_pointer (&renderer->priv->bg_icon_name, g_free);
-  g_clear_object  (&renderer->priv->border_color);
 
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -292,34 +294,8 @@ gimp_view_renderer_set_context (GimpViewRenderer *renderer,
 
   if (context != renderer->context)
     {
-      if (renderer->context)
-        {
-          g_signal_handlers_disconnect_by_func (renderer->context->gimp->config,
-                                                G_CALLBACK (gimp_view_renderer_redraw),
-                                                renderer);
-        }
-
-      GIMP_VIEW_RENDERER_GET_CLASS (renderer)->set_context (renderer, context);
-
-      if (renderer->context)
-        {
-          GimpViewRendererClass *klass  = GIMP_VIEW_RENDERER_GET_CLASS (renderer);
-          GimpCoreConfig        *config = renderer->context->gimp->config;
-
-          g_signal_connect_object (config,
-                                   "notify::viewables-follow-theme",
-                                   G_CALLBACK (gimp_view_renderer_redraw),
-                                   renderer, 0);
-          g_signal_connect_object (config,
-                                   "notify::theme-color-scheme",
-                                   G_CALLBACK (gimp_view_renderer_redraw),
-                                   renderer, 0);
-
-          if (GIMP_GUI_CONFIG (config)->viewables_follow_theme)
-            renderer->surface_bg = klass->follow_theme_bg;
-          else
-            renderer->surface_bg = klass->default_bg;
-        }
+      GIMP_VIEW_RENDERER_GET_CLASS (renderer)->set_context (renderer,
+                                                            context);
 
       if (renderer->viewable)
         gimp_view_renderer_invalidate (renderer);
@@ -350,6 +326,7 @@ gimp_view_renderer_set_viewable (GimpViewRenderer *renderer,
     return;
 
   g_clear_pointer (&renderer->surface, cairo_surface_destroy);
+  g_clear_pointer (&renderer->priv->icon_surface, cairo_surface_destroy);
 
   gimp_view_renderer_free_color_transform (renderer);
 
@@ -473,7 +450,7 @@ gimp_view_renderer_set_size_full (GimpViewRenderer *renderer,
 
 void
 gimp_view_renderer_set_dot_for_dot (GimpViewRenderer *renderer,
-                                    gboolean          dot_for_dot)
+                                    gboolean             dot_for_dot)
 {
   g_return_if_fail (GIMP_IS_VIEW_RENDERER (renderer));
 
@@ -493,47 +470,44 @@ void
 gimp_view_renderer_set_border_type (GimpViewRenderer   *renderer,
                                     GimpViewBorderType  border_type)
 {
-  GeglColor *border_color = NULL;
+  GimpRGB *border_color = &black_color;
 
   g_return_if_fail (GIMP_IS_VIEW_RENDERER (renderer));
 
-  renderer->priv->border_type = border_type;
+  renderer->border_type = border_type;
 
   switch (border_type)
     {
     case GIMP_VIEW_BORDER_BLACK:
-      border_color = gegl_color_new ("black");
+      border_color = &black_color;
       break;
     case GIMP_VIEW_BORDER_WHITE:
-      border_color = gegl_color_new ("white");
+      border_color = &white_color;
       break;
     case GIMP_VIEW_BORDER_GREEN:
-      border_color = gegl_color_new ("green");
-      gegl_color_set_rgba (border_color, 0.0, 0.94, 0.0, 1.0);
+      border_color = &green_color;
       break;
     case GIMP_VIEW_BORDER_RED:
-      border_color = gegl_color_new ("red");
-      break;
-    case GIMP_VIEW_BORDER_STYLE_FG:
-      /* get later when we have a widget */
-      break;
-    case GIMP_VIEW_BORDER_STYLE_BG:
-      border_color = gegl_color_new ("transparent");
+      border_color = &red_color;
       break;
     }
 
-  g_set_object (&renderer->priv->border_color, border_color);
-
-  gimp_view_renderer_update_idle (renderer);
+  gimp_view_renderer_set_border_color (renderer, border_color);
 }
 
-GimpViewBorderType
-gimp_view_renderer_get_border_type (GimpViewRenderer *renderer)
+void
+gimp_view_renderer_set_border_color (GimpViewRenderer *renderer,
+                                     const GimpRGB    *color)
 {
-  g_return_val_if_fail (GIMP_IS_VIEW_RENDERER (renderer),
-                        GIMP_VIEW_BORDER_STYLE_FG);
+  g_return_if_fail (GIMP_IS_VIEW_RENDERER (renderer));
+  g_return_if_fail (color != NULL);
 
-  return renderer->priv->border_type;
+  if (gimp_rgb_distance (&renderer->border_color, color) > RGB_EPSILON)
+    {
+      renderer->border_color = *color;
+
+      gimp_view_renderer_update_idle (renderer);
+    }
 }
 
 void
@@ -678,8 +652,7 @@ gimp_view_renderer_draw (GimpViewRenderer *renderer,
 
       gimp_view_renderer_render_icon (renderer,
                                       widget,
-                                      viewable_class->default_icon_name,
-                                      gtk_widget_get_scale_factor (widget));
+                                      viewable_class->default_icon_name);
       renderer->priv->needs_render = FALSE;
 
       g_type_class_unref (viewable_class);
@@ -691,21 +664,13 @@ gimp_view_renderer_draw (GimpViewRenderer *renderer,
 
   if (renderer->border_width > 0)
     {
-      GeglColor *color;
-      gint       width  = renderer->width  + renderer->border_width;
-      gint       height = renderer->height + renderer->border_width;
-      gdouble    x, y;
-
-      if (renderer->priv->border_color)
-        color = g_object_ref (renderer->priv->border_color);
-      else
-        color = gimp_get_style_color (widget, GTK_STYLE_PROPERTY_COLOR);
+      gint    width  = renderer->width  + renderer->border_width;
+      gint    height = renderer->height + renderer->border_width;
+      gdouble x, y;
 
       cairo_set_line_width (cr, renderer->border_width);
       cairo_set_line_join (cr, CAIRO_LINE_JOIN_ROUND);
-      gimp_cairo_set_source_color (cr, color, NULL, FALSE, widget);
-
-      g_object_unref (color);
+      gimp_cairo_set_source_rgb (cr, &renderer->border_color);
 
       x = (available_width  - width)  / 2.0;
       y = (available_height - height) / 2.0;
@@ -769,80 +734,71 @@ gimp_view_renderer_real_draw (GimpViewRenderer *renderer,
       renderer->priv->needs_render = FALSE;
     }
 
-  if (renderer->priv->bg_icon_name)
+  if (renderer->priv->icon_surface)
     {
-      if (! renderer->priv->pattern)
+      gint  scale_factor = gtk_widget_get_scale_factor (widget);
+      gint  width;
+      gint  height;
+      gint  x, y;
+
+      width  = cairo_image_surface_get_width  (renderer->priv->icon_surface);
+      height = cairo_image_surface_get_height (renderer->priv->icon_surface);
+
+      width  /= scale_factor;
+      height /= scale_factor;
+
+      if (renderer->priv->bg_icon_name)
         {
-          renderer->priv->pattern =
-            gimp_view_renderer_create_background (renderer, widget);
-        }
-
-      cairo_set_source (cr, renderer->priv->pattern);
-      cairo_paint (cr);
-    }
-  else
-    {
-      gint width    = renderer->width;
-      gint height   = renderer->height;
-      gint offset_x = (available_width  - width)  / 2;
-      gint offset_y = (available_height - height) / 2;
-
-      cairo_translate (cr, offset_x, offset_y);
-      cairo_rectangle (cr, 0, 0, width, height);
-
-      switch (renderer->surface_bg)
-        {
-        case GIMP_VIEW_BG_CHECKS:
           if (! renderer->priv->pattern)
             {
-              const GeglColor *rgb1 = gimp_render_check_color1 ();
-              const GeglColor *rgb2 = gimp_render_check_color2 ();
-
               renderer->priv->pattern =
-                gimp_cairo_checkerboard_create (cr, GIMP_CHECK_SIZE_SM,
-                                                rgb1, rgb2);
+                gimp_view_renderer_create_background (renderer, widget);
             }
 
           cairo_set_source (cr, renderer->priv->pattern);
-          cairo_fill (cr);
-          break;
-
-        case GIMP_VIEW_BG_WHITE:
-          cairo_set_source_rgb (cr, 1.0, 1.0, 1.0);
-          cairo_fill (cr);
-          break;
-
-        case GIMP_VIEW_BG_STYLE:
-          break;
+          cairo_paint (cr);
         }
 
-      cairo_translate (cr, -offset_x, -offset_y);
-    }
-
-  if (renderer->surface)
-    {
-      gdouble scale_x;
-      gdouble scale_y;
-      gint    width;
-      gint    height;
-      gint    x, y;
-
-      width  = cairo_image_surface_get_width  (renderer->surface);
-      height = cairo_image_surface_get_height (renderer->surface);
-
-      cairo_surface_get_device_scale (renderer->surface, &scale_x, &scale_y);
-
-      width  /= scale_x;
-      height /= scale_y;
-
       x = (available_width  - width)  / 2;
       y = (available_height - height) / 2;
 
+      cairo_set_source_surface (cr, renderer->priv->icon_surface, x, y);
       cairo_rectangle (cr, x, y, width, height);
-
-      cairo_set_source_surface (cr, renderer->surface, x, y);
       cairo_fill (cr);
     }
+  else if (renderer->surface)
+    {
+      cairo_content_t content  = cairo_surface_get_content (renderer->surface);
+      gint            width    = renderer->width;
+      gint            height   = renderer->height;
+      gint            offset_x = (available_width  - width)  / 2;
+      gint            offset_y = (available_height - height) / 2;
+
+      cairo_translate (cr, offset_x, offset_y);
+
+      cairo_rectangle (cr, 0, 0, width, height);
+
+      if (content == CAIRO_CONTENT_COLOR_ALPHA)
+        {
+          if (! renderer->priv->pattern)
+            {
+              GimpRGB rgb1;
+              GimpRGB rgb2;
+
+              gegl_color_get_pixel ((GeglColor *) gimp_render_check_color1 (), babl_format ("R'G'B'A double"), &rgb1);
+              gegl_color_get_pixel ((GeglColor *) gimp_render_check_color2 (), babl_format ("R'G'B'A double"), &rgb2);
+              renderer->priv->pattern = gimp_cairo_checkerboard_create (cr, GIMP_CHECK_SIZE_SM, &rgb1, &rgb2);
+            }
+
+          cairo_set_source (cr, renderer->priv->pattern);
+          cairo_fill_preserve (cr);
+        }
+
+      cairo_set_source_surface (cr, renderer->surface, 0, 0);
+      cairo_fill (cr);
+
+      cairo_translate (cr, - offset_x, - offset_y);
+    }
 }
 
 static void
@@ -852,53 +808,30 @@ gimp_view_renderer_real_render (GimpViewRenderer *renderer,
   GdkPixbuf   *pixbuf;
   GimpTempBuf *temp_buf;
   const gchar *icon_name;
-  GeglColor   *fg_color     = NULL;
-  GimpViewBG   inside_bg    = GIMP_VIEW_BG_CHECKS;
-  GimpViewBG   outside_bg   = GIMP_VIEW_BG_WHITE;
   gint         scale_factor = gtk_widget_get_scale_factor (widget);
 
-  if (renderer->context &&
-      GIMP_GUI_CONFIG (renderer->context->gimp->config)->viewables_follow_theme)
-    {
-      fg_color = gimp_get_style_color (widget, GTK_STYLE_PROPERTY_COLOR);
-
-      inside_bg  = GIMP_VIEW_BG_STYLE;
-      outside_bg = GIMP_VIEW_BG_STYLE;
-    }
-
   pixbuf = gimp_viewable_get_pixbuf (renderer->viewable,
                                      renderer->context,
                                      renderer->width  * scale_factor,
-                                     renderer->height * scale_factor,
-                                     fg_color);
+                                     renderer->height * scale_factor);
   if (pixbuf)
     {
-      gimp_view_renderer_render_pixbuf (renderer, widget,
-                                        pixbuf, scale_factor);
-      g_clear_object (&fg_color);
+      gimp_view_renderer_render_pixbuf (renderer, widget, pixbuf);
       return;
     }
 
   temp_buf = gimp_viewable_get_preview (renderer->viewable,
                                         renderer->context,
                                         renderer->width,
-                                        renderer->height,
-                                        fg_color);
+                                        renderer->height);
   if (temp_buf)
     {
-      gimp_view_renderer_render_temp_buf_simple (renderer, widget,
-                                                 temp_buf,
-                                                 inside_bg,
-                                                 outside_bg);
-      g_clear_object (&fg_color);
+      gimp_view_renderer_render_temp_buf_simple (renderer, widget, temp_buf);
       return;
     }
 
   icon_name = gimp_viewable_get_icon_name (renderer->viewable);
-  gimp_view_renderer_render_icon (renderer, widget,
-                                  icon_name, scale_factor);
-
-  g_clear_object (&fg_color);
+  gimp_view_renderer_render_icon (renderer, widget, icon_name);
 }
 
 static void
@@ -933,9 +866,7 @@ gimp_view_renderer_config_notify (GObject          *config,
 void
 gimp_view_renderer_render_temp_buf_simple (GimpViewRenderer *renderer,
                                            GtkWidget        *widget,
-                                           GimpTempBuf      *temp_buf,
-                                           GimpViewBG        inside_bg,
-                                           GimpViewBG        outside_bg)
+                                           GimpTempBuf      *temp_buf)
 {
   gint temp_buf_x = 0;
   gint temp_buf_y = 0;
@@ -957,8 +888,8 @@ gimp_view_renderer_render_temp_buf_simple (GimpViewRenderer *renderer,
   gimp_view_renderer_render_temp_buf (renderer, widget, temp_buf,
                                       temp_buf_x, temp_buf_y,
                                       -1,
-                                      inside_bg,
-                                      outside_bg);
+                                      GIMP_VIEW_BG_CHECKS,
+                                      GIMP_VIEW_BG_WHITE);
 }
 
 void
@@ -971,11 +902,12 @@ gimp_view_renderer_render_temp_buf (GimpViewRenderer *renderer,
                                     GimpViewBG        inside_bg,
                                     GimpViewBG        outside_bg)
 {
-  g_clear_pointer (&renderer->surface, cairo_surface_destroy);
+  g_clear_pointer (&renderer->priv->icon_surface, cairo_surface_destroy);
 
-  renderer->surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
-                                                  renderer->width,
-                                                  renderer->height);
+  if (! renderer->surface)
+    renderer->surface = cairo_image_surface_create (CAIRO_FORMAT_RGB24,
+                                                    renderer->width,
+                                                    renderer->height);
 
   gimp_view_render_temp_buf_to_surface (renderer,
                                         widget,
@@ -994,11 +926,11 @@ gimp_view_renderer_render_temp_buf (GimpViewRenderer *renderer,
 void
 gimp_view_renderer_render_pixbuf (GimpViewRenderer *renderer,
                                   GtkWidget        *widget,
-                                  GdkPixbuf        *pixbuf,
-                                  gint              pixbuf_scale)
+                                  GdkPixbuf        *pixbuf)
 {
   GimpColorTransform *transform;
   const Babl         *format;
+  gint                scale_factor;
 
   g_clear_pointer (&renderer->surface, cairo_surface_destroy);
 
@@ -1043,19 +975,21 @@ gimp_view_renderer_render_pixbuf (GimpViewRenderer *renderer,
       g_object_ref (pixbuf);
     }
 
-  renderer->surface = gdk_cairo_surface_create_from_pixbuf (pixbuf,
-                                                            pixbuf_scale,
-                                                            NULL);
+  scale_factor = gtk_widget_get_scale_factor (widget);
+
+  g_clear_pointer (&renderer->priv->icon_surface, cairo_surface_destroy);
+  renderer->priv->icon_surface =
+    gdk_cairo_surface_create_from_pixbuf (pixbuf, scale_factor, NULL);
   g_object_unref (pixbuf);
 }
 
 void
 gimp_view_renderer_render_icon (GimpViewRenderer *renderer,
                                 GtkWidget        *widget,
-                                const gchar      *icon_name,
-                                gint              icon_scale)
+                                const gchar      *icon_name)
 {
   GdkPixbuf *pixbuf;
+  gint       scale_factor;
   gint       width;
   gint       height;
 
@@ -1063,37 +997,40 @@ gimp_view_renderer_render_icon (GimpViewRenderer *renderer,
   g_return_if_fail (GTK_IS_WIDGET (widget));
   g_return_if_fail (icon_name != NULL);
 
+  g_clear_pointer (&renderer->priv->icon_surface, cairo_surface_destroy);
   g_clear_pointer (&renderer->surface, cairo_surface_destroy);
 
+  scale_factor = gtk_widget_get_scale_factor (widget);
+
   pixbuf = gimp_widget_load_icon (widget, icon_name,
                                   MIN (renderer->width, renderer->height));
   width  = gdk_pixbuf_get_width (pixbuf);
   height = gdk_pixbuf_get_height (pixbuf);
 
-  if (width  > renderer->width  * icon_scale ||
-      height > renderer->height * icon_scale)
+  if (width  > renderer->width  * scale_factor ||
+      height > renderer->height * scale_factor)
     {
       GdkPixbuf *scaled_pixbuf;
 
       gimp_viewable_calc_preview_size (width, height,
-                                       renderer->width  * icon_scale,
-                                       renderer->height * icon_scale,
+                                       renderer->width  * scale_factor,
+                                       renderer->height * scale_factor,
                                        TRUE, 1.0, 1.0,
                                        &width, &height,
                                        NULL);
 
       scaled_pixbuf = gdk_pixbuf_scale_simple (pixbuf,
-                                               width  * icon_scale,
-                                               height * icon_scale,
+                                               width  * scale_factor,
+                                               height * scale_factor,
                                                GDK_INTERP_BILINEAR);
 
       g_object_unref (pixbuf);
       pixbuf = scaled_pixbuf;
     }
 
-  renderer->surface = gdk_cairo_surface_create_from_pixbuf (pixbuf,
-                                                            icon_scale,
-                                                            NULL);
+  g_clear_pointer (&renderer->priv->icon_surface, cairo_surface_destroy);
+  renderer->priv->icon_surface =
+    gdk_cairo_surface_create_from_pixbuf (pixbuf, scale_factor, NULL);
   g_object_unref (pixbuf);
 }
 
@@ -1177,7 +1114,6 @@ gimp_view_renderer_free_color_transform (GimpViewRenderer *renderer)
   gimp_view_renderer_invalidate (renderer);
 }
 
-
 /*  private functions  */
 
 static void
@@ -1221,21 +1157,17 @@ gimp_view_render_temp_buf_to_surface (GimpViewRenderer *renderer,
 
   cr = cairo_create (surface);
 
-  cairo_set_operator (cr, CAIRO_OPERATOR_CLEAR);
-  cairo_paint (cr);
-  cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
-
   if (outside_bg == GIMP_VIEW_BG_CHECKS ||
       inside_bg  == GIMP_VIEW_BG_CHECKS)
     {
       if (! renderer->priv->pattern)
         {
-          const GeglColor *rgb1 = gimp_render_check_color1 ();
-          const GeglColor *rgb2 = gimp_render_check_color2 ();
+          GimpRGB rgb1;
+          GimpRGB rgb2;
 
-          renderer->priv->pattern =
-            gimp_cairo_checkerboard_create (cr, GIMP_CHECK_SIZE_SM,
-                                            rgb1, rgb2);
+          gegl_color_get_pixel ((GeglColor *) gimp_render_check_color1 (), babl_format ("R'G'B'A double"), &rgb1);
+          gegl_color_get_pixel ((GeglColor *) gimp_render_check_color2 (), babl_format ("R'G'B'A double"), &rgb2);
+          renderer->priv->pattern = gimp_cairo_checkerboard_create (cr, GIMP_CHECK_SIZE_SM, &rgb1, &rgb2);
         }
     }
 
@@ -1243,18 +1175,15 @@ gimp_view_render_temp_buf_to_surface (GimpViewRenderer *renderer,
     {
     case GIMP_VIEW_BG_CHECKS:
       cairo_set_source (cr, renderer->priv->pattern);
-      cairo_paint (cr);
       break;
 
     case GIMP_VIEW_BG_WHITE:
       cairo_set_source_rgb (cr, 1.0, 1.0, 1.0);
-      cairo_paint (cr);
-      break;
-
-    case GIMP_VIEW_BG_STYLE:
       break;
     }
 
+  cairo_paint (cr);
+
   if (! gimp_rectangle_intersect (0, 0,
                                   surface_width, surface_height,
                                   temp_buf_x, temp_buf_y,
@@ -1266,9 +1195,8 @@ gimp_view_render_temp_buf_to_surface (GimpViewRenderer *renderer,
       return;
     }
 
-  if (inside_bg != outside_bg                 &&
-      babl_format_has_alpha (temp_buf_format) &&
-      channel == -1)
+  if (inside_bg != outside_bg &&
+      babl_format_has_alpha (temp_buf_format) && channel == -1)
     {
       cairo_rectangle (cr, x, y, width, height);
 
@@ -1276,31 +1204,28 @@ gimp_view_render_temp_buf_to_surface (GimpViewRenderer *renderer,
         {
         case GIMP_VIEW_BG_CHECKS:
           cairo_set_source (cr, renderer->priv->pattern);
-          cairo_fill (cr);
           break;
 
         case GIMP_VIEW_BG_WHITE:
           cairo_set_source_rgb (cr, 1.0, 1.0, 1.0);
-          cairo_fill (cr);
-          break;
-
-        case GIMP_VIEW_BG_STYLE:
           break;
         }
+
+      cairo_fill (cr);
     }
 
-  if (channel == -1)
+  if (babl_format_has_alpha (temp_buf_format) && channel == -1)
     {
       GimpColorTransform *transform;
       GeglBuffer         *src_buffer;
       GeglBuffer         *dest_buffer;
-      cairo_surface_t    *tmp_surface;
+      cairo_surface_t    *alpha_surface;
 
-      tmp_surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
-                                                width, height);
+      alpha_surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
+                                                  width, height);
 
       src_buffer  = gimp_temp_buf_create_buffer (temp_buf);
-      dest_buffer = gimp_cairo_surface_create_buffer (tmp_surface, NULL);
+      dest_buffer = gimp_cairo_surface_create_buffer (alpha_surface, NULL);
 
       transform =
         gimp_view_renderer_get_color_transform (renderer, widget,
@@ -1331,14 +1256,56 @@ gimp_view_render_temp_buf_to_surface (GimpViewRenderer *renderer,
       g_object_unref (src_buffer);
       g_object_unref (dest_buffer);
 
-      cairo_surface_mark_dirty (tmp_surface);
+      cairo_surface_mark_dirty (alpha_surface);
 
       cairo_translate (cr, x, y);
       cairo_rectangle (cr, 0, 0, width, height);
-      cairo_set_source_surface (cr, tmp_surface, 0, 0);
+      cairo_set_source_surface (cr, alpha_surface, 0, 0);
       cairo_fill (cr);
 
-      cairo_surface_destroy (tmp_surface);
+      cairo_surface_destroy (alpha_surface);
+    }
+  else if (channel == -1)
+    {
+      GimpColorTransform *transform;
+      GeglBuffer         *src_buffer;
+      GeglBuffer         *dest_buffer;
+
+      cairo_surface_flush (surface);
+
+      src_buffer  = gimp_temp_buf_create_buffer (temp_buf);
+      dest_buffer = gimp_cairo_surface_create_buffer (surface, NULL);
+
+      transform =
+        gimp_view_renderer_get_color_transform (renderer, widget,
+                                                gegl_buffer_get_format (src_buffer),
+                                                gegl_buffer_get_format (dest_buffer));
+
+      if (transform)
+        {
+          gimp_color_transform_process_buffer (transform,
+                                               src_buffer,
+                                               GEGL_RECTANGLE (x - temp_buf_x,
+                                                               y - temp_buf_y,
+                                                               width, height),
+                                               dest_buffer,
+                                               GEGL_RECTANGLE (x, y, 0, 0));
+        }
+      else
+        {
+          gimp_gegl_buffer_copy (src_buffer,
+                                 GEGL_RECTANGLE (x - temp_buf_x,
+                                                 y - temp_buf_y,
+                                                 width, height),
+                                 GEGL_ABYSS_NONE,
+                                 dest_buffer,
+                                 GEGL_RECTANGLE (x, y, 0, 0));
+        }
+
+      g_object_unref (src_buffer);
+      g_object_unref (dest_buffer);
+
+      cairo_surface_mark_dirty (surface);
     }
   else
     {
@@ -1364,26 +1331,31 @@ gimp_view_render_temp_buf_to_surface (GimpViewRenderer *renderer,
       dest += y * dest_stride + x * 4;
 
       fish = babl_fish (temp_buf_format,
-                        babl_format ("R~G~B~ u8"));
+                        babl_format ("cairo-RGB24"));
 
-      for (i = 0; i < height; i++)
+      for (i = y; i < (y + height); i++)
         {
-          guchar        line[width * 3];
-          const guchar *s = line;
-          guint32      *d = (guint32*) dest;
+          const guchar *s = src;
+          guchar       *d = dest;
           gint          j;
 
-          babl_process (fish, src, line, width);
-
-          for (j = 0; j < width; j++)
+          for (j = x; j < (x + width); j++, d += 4, s += bytes)
             {
-              *d = s[channel] | s[channel] << 8 | s[channel] << 16;
+              if (bytes > 2)
+                {
+                  guchar pixel[4] = { s[channel], s[channel], s[channel], 255 };
 
-              s += 3;
-              d += 1;
+                  babl_process (fish, pixel, d, 1);
+                }
+              else
+                {
+                  guchar pixel[2] = { s[channel], 255 };
+
+                  babl_process (fish, pixel, d, 1);
+                }
             }
 
-          src  += rowstride;
+          src += rowstride;
           dest += dest_stride;
         }
 
@@ -1421,19 +1393,3 @@ gimp_view_renderer_create_background (GimpViewRenderer *renderer,
 
   return pattern;
 }
-
-static void
-gimp_view_renderer_redraw (GimpGuiConfig    *config,
-                           const GParamSpec *pspec,
-                           GimpViewRenderer *renderer)
-{
-  GimpViewRendererClass *klass = GIMP_VIEW_RENDERER_GET_CLASS (renderer);
-
-  if (config->viewables_follow_theme)
-    renderer->surface_bg = klass->follow_theme_bg;
-  else
-    renderer->surface_bg = klass->default_bg;
-
-  gimp_view_renderer_invalidate (renderer);
-  gimp_view_renderer_update (renderer);
-}
