@@ -24,8 +24,6 @@
 
 #include <stdlib.h>
 
-#include "libgimpcolor/gimpcolor-private.h"
-
 #include <libgimp/gimp.h>
 #include <libgimp/gimpui.h>
 
@@ -94,13 +92,13 @@ static GimpProcedure  * despeckle_create_procedure (GimpPlugIn           *plug_i
 static GimpValueArray * despeckle_run              (GimpProcedure        *procedure,
                                                     GimpRunMode           run_mode,
                                                     GimpImage            *image,
+                                                    gint                  n_drawables,
                                                     GimpDrawable        **drawables,
                                                     GimpProcedureConfig  *config,
                                                     gpointer              run_data);
 
-static gboolean         despeckle                  (GimpDrawable         *drawable,
-                                                    GObject              *config,
-                                                    GError              **error);
+static void             despeckle                  (GimpDrawable         *drawable,
+                                                    GObject              *config);
 static void             despeckle_median           (GObject              *config,
                                                     guchar               *src,
                                                     guchar               *dst,
@@ -183,34 +181,30 @@ despeckle_create_procedure (GimpPlugIn  *plug_in,
                                       "Copyright 1997-1998 by Michael Sweet",
                                       PLUG_IN_VERSION);
 
-      gimp_procedure_add_int_argument (procedure, "radius",
-                                       _("R_adius"),
-                                       _("Filter box radius"),
-                                       1, MAX_RADIUS, 3,
-                                       G_PARAM_READWRITE);
+      GIMP_PROC_ARG_INT (procedure, "radius",
+                         _("R_adius"),
+                         _("Filter box radius"),
+                         1, MAX_RADIUS, 3,
+                         G_PARAM_READWRITE);
 
-      gimp_procedure_add_choice_argument (procedure, "type",
-                                          _("_Filter Type"),
-                                          _("Filter type"),
-                                          gimp_choice_new_with_values ("median",             0,                 _("Median"),             NULL,
-                                                                       "adaptive",           FILTER_ADAPTIVE,   _("Adaptive"),           NULL,
-                                                                       "recursive-median",   FILTER_RECURSIVE, _("Recursive-Median"),   NULL,
-                                                                       "recursive-adaptive", 3,                 _("Recursive-Adaptive"), NULL,
-                                                                       NULL),
-                                          "adaptive",
-                                          G_PARAM_READWRITE);
+      GIMP_PROC_ARG_INT (procedure, "type",
+                         _("_Filter Type"),
+                         _("Filter type { MEDIAN (0), ADAPTIVE (1), "
+                         "RECURSIVE-MEDIAN (2), RECURSIVE-ADAPTIVE (3) }"),
+                         0, 3, FILTER_ADAPTIVE,
+                         G_PARAM_READWRITE);
 
-      gimp_procedure_add_int_argument (procedure, "black",
-                                       _("_Black level"),
-                                       _("Black level"),
-                                       -1, 255, 7,
-                                       G_PARAM_READWRITE);
+      GIMP_PROC_ARG_INT (procedure, "black",
+                         _("_Black level"),
+                         _("Black level"),
+                         -1, 255, 7,
+                         G_PARAM_READWRITE);
 
-      gimp_procedure_add_int_argument (procedure, "white",
-                                       _("_White level"),
-                                       _("White level"),
-                                       0, 256, 248,
-                                       G_PARAM_READWRITE);
+      GIMP_PROC_ARG_INT (procedure, "white",
+                         _("_White level"),
+                         _("White level"),
+                         0, 256, 248,
+                         G_PARAM_READWRITE);
     }
 
   return procedure;
@@ -220,17 +214,19 @@ static GimpValueArray *
 despeckle_run (GimpProcedure        *procedure,
                GimpRunMode           run_mode,
                GimpImage            *image,
+               gint                  n_drawables,
                GimpDrawable        **drawables,
                GimpProcedureConfig  *config,
                gpointer              run_data)
 {
   GimpDrawable *drawable;
-  GError       *error = NULL;
 
   gegl_init (NULL, NULL);
 
-  if (gimp_core_object_array_get_length ((GObject **) drawables) != 1)
+  if (n_drawables != 1)
     {
+      GError *error = NULL;
+
       g_set_error (&error, GIMP_PLUG_IN_ERROR, 0,
                    _("Procedure '%s' only works with one drawable."),
                    PLUG_IN_PROC);
@@ -250,10 +246,7 @@ despeckle_run (GimpProcedure        *procedure,
   if (run_mode == GIMP_RUN_INTERACTIVE && ! despeckle_dialog (procedure, G_OBJECT (config), drawable))
     return gimp_procedure_new_return_values (procedure, GIMP_PDB_CANCEL, NULL);
 
-  if (! despeckle (drawable, G_OBJECT (config), &error))
-      return gimp_procedure_new_return_values (procedure,
-                                               GIMP_PDB_EXECUTION_ERROR,
-                                               error);
+  despeckle (drawable, G_OBJECT (config));
 
   return gimp_procedure_new_return_values (procedure, GIMP_PDB_SUCCESS, NULL);
 }
@@ -326,10 +319,9 @@ get_u8_format (GimpDrawable *drawable)
     }
 }
 
-static gboolean
+static void
 despeckle (GimpDrawable *drawable,
-           GObject      *config,
-           GError      **error)
+           GObject      *config)
 {
   GeglBuffer *src_buffer;
   GeglBuffer *dest_buffer;
@@ -339,11 +331,10 @@ despeckle (GimpDrawable *drawable,
   gint        img_bpp;
   gint        x, y;
   gint        width, height;
-  gsize       bufsize = 0;
 
   if (! gimp_drawable_mask_intersect (drawable,
                                       &x, &y, &width, &height))
-    return TRUE;
+    return;
 
   format  = get_u8_format (drawable);
   img_bpp = babl_format_get_bytes_per_pixel (format);
@@ -351,26 +342,8 @@ despeckle (GimpDrawable *drawable,
   src_buffer  = gimp_drawable_get_buffer (drawable);
   dest_buffer = gimp_drawable_get_shadow_buffer (drawable);
 
-  if (! g_size_checked_mul (&bufsize, width,   height) ||
-      ! g_size_checked_mul (&bufsize, bufsize, img_bpp))
-    {
-      g_set_error (error, GIMP_PLUG_IN_ERROR, 0,
-                   _("Image dimensions too large: width %d x height %d"),
-                   width, height);
-      return FALSE;
-    }
-
-  src = g_try_malloc (bufsize);
-  dst = g_try_malloc (bufsize);
-
-  if (src == NULL || dst == NULL)
-    {
-      g_set_error (error, GIMP_PLUG_IN_ERROR, 0,
-                   _("There was not enough memory to complete the operation."));
-      g_free (src);
-
-      return FALSE;
-    }
+  src = g_new (guchar, width * height * img_bpp);
+  dst = g_new (guchar, width * height * img_bpp);
 
   gegl_buffer_get (src_buffer, GEGL_RECTANGLE (x, y, width, height), 1.0,
                    format, src,
@@ -391,8 +364,6 @@ despeckle (GimpDrawable *drawable,
 
   g_free (dst);
   g_free (src);
-
-  return TRUE;
 }
 
 static gboolean
@@ -400,12 +371,13 @@ despeckle_dialog (GimpProcedure *procedure,
                   GObject       *config,
                   GimpDrawable  *drawable)
 {
-  GtkWidget *dialog;
-  GtkWidget *preview;
-  GtkWidget *vbox;
-  GtkWidget *scale;
-  GtkWidget *combo;
-  gboolean   run;
+  GtkWidget    *dialog;
+  GtkWidget    *preview;
+  GtkWidget    *vbox;
+  GtkWidget    *scale;
+  GtkWidget    *combo;
+  GtkListStore *store;
+  gboolean      run;
 
   gimp_ui_init (PLUG_IN_BINARY);
 
@@ -413,27 +385,35 @@ despeckle_dialog (GimpProcedure *procedure,
                                       GIMP_PROCEDURE_CONFIG (config),
                                       _("Despeckle"));
 
-  combo = gimp_procedure_dialog_get_widget (GIMP_PROCEDURE_DIALOG (dialog),
-                                            "type", G_TYPE_NONE);
+  gimp_window_set_transient (GTK_WINDOW (dialog));
+
+  store = gimp_int_store_new (_("Median"),             0,
+                              _("Adaptive"),           FILTER_ADAPTIVE,
+                              _("Recursive-Median"),   FILTER_RECURSIVE,
+                              _("Recursive-Adaptive"), 3,
+                              NULL);
+  combo = gimp_procedure_dialog_get_int_combo (GIMP_PROCEDURE_DIALOG (dialog),
+                                               "type",
+                                               GIMP_INT_STORE (store));
   gtk_widget_set_margin_bottom (combo, 12);
 
   /*
    * Box size (diameter) control...
    */
-  scale = gimp_procedure_dialog_get_spin_scale (GIMP_PROCEDURE_DIALOG (dialog),
+  scale = gimp_procedure_dialog_get_scale_entry (GIMP_PROCEDURE_DIALOG (dialog),
                                                 "radius", 1.0);
   gtk_widget_set_margin_bottom (scale, 12);
   /*
    * Black level control...
    */
-  scale = gimp_procedure_dialog_get_spin_scale (GIMP_PROCEDURE_DIALOG (dialog),
-                                                "black", 1.0);
+  scale = gimp_procedure_dialog_get_scale_entry (GIMP_PROCEDURE_DIALOG (dialog),
+                                                 "black", 1.0);
   gtk_widget_set_margin_bottom (scale, 12);
   /*
    * White level control...
    */
-  gimp_procedure_dialog_get_spin_scale (GIMP_PROCEDURE_DIALOG (dialog),
-                                        "white", 1.0);
+  gimp_procedure_dialog_get_scale_entry (GIMP_PROCEDURE_DIALOG (dialog),
+                                         "white", 1.0);
 
   vbox = gimp_procedure_dialog_fill_box (GIMP_PROCEDURE_DIALOG (dialog),
                                          "despeckle-vbox",
@@ -471,9 +451,8 @@ static void
 preview_update (GtkWidget *widget,
                 GObject   *config)
 {
-  GimpPreview  *preview  = GIMP_PREVIEW (widget);
+  GimpPreview  *preview = GIMP_PREVIEW (widget);
   GimpDrawable *drawable = g_object_get_data (config, "drawable");
-  gsize         bufsize  = 0;
   GeglBuffer   *src_buffer;
   const Babl   *format;
   guchar       *dst;
@@ -490,18 +469,8 @@ preview_update (GtkWidget *widget,
 
   src_buffer = gimp_drawable_get_buffer (drawable);
 
-  if (! g_size_checked_mul (&bufsize, width,   height) ||
-      ! g_size_checked_mul (&bufsize, bufsize, img_bpp))
-      return;
-
-  src = g_try_malloc (bufsize);
-  dst = g_try_malloc (bufsize);
-
-  if (src == NULL || dst == NULL)
-    {
-      g_free (src);
-      return;
-    }
+  dst = g_new (guchar, width * height * img_bpp);
+  src = g_new (guchar, width * height * img_bpp);
 
   gegl_buffer_get (src_buffer, GEGL_RECTANGLE (x1, y1, width, height), 1.0,
                    format, src,
@@ -778,11 +747,10 @@ despeckle_median (GObject  *config,
 
   g_object_get (config,
                 "radius", &radius,
+                "type",   &filter_type,
                 "black",  &black_level,
                 "white",  &white_level,
                 NULL);
-  filter_type = gimp_procedure_config_get_choice_id (GIMP_PROCEDURE_CONFIG (config),
-                                                     "type");
 
   memset (&histogram, 0, sizeof(histogram));
   progress     = 0;
