@@ -47,11 +47,15 @@
 #include <errno.h>
 #include <string.h>
 
+#include <gio/gio.h>
+#include <glib/gstdio.h>
+
 #include <tiffio.h>
 
 #include <libgimp/gimp.h>
 #include <libgimp/gimpui.h>
 
+#include "file-tiff.h"
 #include "file-tiff-io.h"
 #include "file-tiff-load.h"
 
@@ -63,18 +67,11 @@
 
 typedef struct
 {
-  gint      compression;
-  gint      fillorder;
-  gboolean  save_transp_pixels;
-} TiffSaveVals;
-
-typedef struct
-{
-  gint32      ID;
-  GeglBuffer *buffer;
-  const Babl *format;
-  guchar     *pixels;
-  guchar     *pixel;
+  GimpDrawable *drawable;
+  GeglBuffer   *buffer;
+  const Babl   *format;
+  guchar       *pixels;
+  guchar       *pixel;
 } ChannelData;
 
 typedef enum
@@ -114,12 +111,6 @@ static void               load_separate    (TIFF              *tif,
                                             TiffColorMode      tiff_mode,
                                             gboolean           is_signed,
                                             gint               extra);
-static void               load_paths       (TIFF              *tif,
-                                            gint               image,
-                                            gint               width,
-                                            gint               height,
-                                            gint               offset_x,
-                                            gint               offset_y);
 
 static gboolean   is_non_conformant_tiff   (gushort            photomet,
                                             gushort            spp);
@@ -162,11 +153,6 @@ static void       tiff_dialog_show_reduced (GtkWidget         *toggle,
                                             gpointer           data);
 
 
-static TiffSaveVals tsvals =
-{
-  COMPRESSION_NONE,    /*  compression    */
-  TRUE,                /*  alpha handling */
-};
 
 /* Grayscale conversion mappings */
 static const guchar _1_to_8_bitmap [2] =
@@ -273,29 +259,35 @@ get_extra_channels_count (gushort photomet, gushort spp, gboolean alpha)
 }
 
 GimpPDBStatusType
-load_image (GFile        *file,
-            GimpRunMode   run_mode,
-            gint32       *image,
-            gboolean     *resolution_loaded,
-            gboolean     *profile_loaded,
-            GError      **error)
+load_image (GFile                *file,
+            GimpRunMode           run_mode,
+            GimpImage           **image,
+            gboolean             *resolution_loaded,
+            gboolean             *profile_loaded,
+            gboolean             *ps_metadata_loaded,
+            GimpProcedureConfig  *config,
+            GError              **error)
 {
   TIFF              *tif;
   TiffSelectedPages  pages;
 
-  GList             *images_list      = NULL;
-  DefaultExtra       default_extra    = GIMP_TIFF_LOAD_UNASSALPHA;
-  gint               first_image_type = GIMP_RGB;
-  gint               min_row          = G_MAXINT;
-  gint               min_col          = G_MAXINT;
-  gint               max_row          = 0;
-  gint               max_col          = 0;
+  GList             *images_list        = NULL;
+  DefaultExtra       default_extra      = GIMP_TIFF_LOAD_UNASSALPHA;
+  gint               first_image_type   = GIMP_RGB;
+  gint               min_row            = G_MAXINT;
+  gint               min_col            = G_MAXINT;
+  gint               max_row            = 0;
+  gint               max_col            = 0;
+  gboolean           save_transp_pixels = FALSE;
   GimpColorProfile  *first_profile      = NULL;
   const gchar       *extra_message      = NULL;
   gint               li;
   gint               selectable_pages;
+  gchar             *photoshop_data;
+  gint32             photoshop_len;
+  gboolean           is_cmyk            = FALSE;
 
-  *image = 0;
+  *image = NULL;
   gimp_progress_init_printf (_("Opening '%s'"),
                              gimp_file_get_utf8_name (file));
 
@@ -309,12 +301,8 @@ load_image (GFile        *file,
       return  GIMP_PDB_EXECUTION_ERROR;
     }
 
-  pages.target = GIMP_PAGE_SELECTOR_TARGET_LAYERS;
-  gimp_get_data (LOAD_PROC "-target", &pages.target);
-
-  pages.keep_empty_space = TRUE;
-  gimp_get_data (LOAD_PROC "-keep-empty-space",
-                 &pages.keep_empty_space);
+  g_object_get (config, "target", &pages.target, NULL);
+  g_object_get (config, "keep-empty-space", &pages.keep_empty_space, NULL);
 
   pages.n_pages = pages.o_pages = TIFFNumberOfDirectories (tif);
   if (pages.n_pages == 0)
@@ -533,11 +521,8 @@ load_image (GFile        *file,
         }
     }
 
-  gimp_set_data (LOAD_PROC "-target",
-                 &pages.target, sizeof (pages.target));
-  gimp_set_data (LOAD_PROC "-keep-empty-space",
-                 &pages.keep_empty_space,
-                 sizeof (pages.keep_empty_space));
+  g_object_set (config, "target", pages.target, NULL);
+  g_object_set (config, "keep-empty-space", pages.keep_empty_space, NULL);
 
   /* We will loop through the all pages in case of multipage TIFF
    * and load every page as a separate layer.
@@ -560,7 +545,7 @@ load_image (GFile        *file,
       gint              rows;
       gboolean          alpha;
       gint              image_type           = GIMP_RGB;
-      gint              layer;
+      GimpLayer        *layer;
       gint              layer_type           = GIMP_RGB_IMAGE;
       float             layer_offset_x       = 0.0;
       float             layer_offset_y       = 0.0;
@@ -569,12 +554,12 @@ load_image (GFile        *file,
       gushort           extra;
       gushort          *extra_types;
       ChannelData      *channel = NULL;
-      uint16            planar  = PLANARCONFIG_CONTIG;
+      uint16_t          planar  = PLANARCONFIG_CONTIG;
       TiffColorMode     tiff_mode;
       gboolean          is_signed;
       gint              i;
       gboolean          worst_case = FALSE;
-      TiffSaveVals      save_vals;
+      gint              gimp_compression = GIMP_COMPRESSION_NONE;
       const gchar      *name;
 
       if (TIFFSetDirectory (tif, pages.pages[li]) == 0)
@@ -645,7 +630,7 @@ load_image (GFile        *file,
           if (profile_linear)
             image_precision = GIMP_PRECISION_U8_LINEAR;
           else
-            image_precision = GIMP_PRECISION_U8_GAMMA;
+            image_precision = GIMP_PRECISION_U8_NON_LINEAR;
 
           type = babl_type ("u8");
           break;
@@ -656,7 +641,7 @@ load_image (GFile        *file,
               if (profile_linear)
                 image_precision = GIMP_PRECISION_HALF_LINEAR;
               else
-                image_precision = GIMP_PRECISION_HALF_GAMMA;
+                image_precision = GIMP_PRECISION_HALF_NON_LINEAR;
 
               type = babl_type ("half");
             }
@@ -665,7 +650,7 @@ load_image (GFile        *file,
               if (profile_linear)
                 image_precision = GIMP_PRECISION_U16_LINEAR;
               else
-                image_precision = GIMP_PRECISION_U16_GAMMA;
+                image_precision = GIMP_PRECISION_U16_NON_LINEAR;
 
               type = babl_type ("u16");
             }
@@ -677,7 +662,7 @@ load_image (GFile        *file,
               if (profile_linear)
                 image_precision = GIMP_PRECISION_FLOAT_LINEAR;
               else
-                image_precision = GIMP_PRECISION_FLOAT_GAMMA;
+                image_precision = GIMP_PRECISION_FLOAT_NON_LINEAR;
 
               type = babl_type ("float");
             }
@@ -686,7 +671,7 @@ load_image (GFile        *file,
               if (profile_linear)
                 image_precision = GIMP_PRECISION_U32_LINEAR;
               else
-                image_precision = GIMP_PRECISION_U32_GAMMA;
+                image_precision = GIMP_PRECISION_U32_NON_LINEAR;
 
               type = babl_type ("u32");
             }
@@ -696,7 +681,7 @@ load_image (GFile        *file,
           if (profile_linear)
             image_precision = GIMP_PRECISION_DOUBLE_LINEAR;
           else
-            image_precision = GIMP_PRECISION_DOUBLE_GAMMA;
+            image_precision = GIMP_PRECISION_DOUBLE_NON_LINEAR;
 
           type = babl_type ("double");
           break;
@@ -778,13 +763,13 @@ load_image (GFile        *file,
       if (extra > 0 && (extra_types[0] == EXTRASAMPLE_ASSOCALPHA))
         {
           alpha = TRUE;
-          tsvals.save_transp_pixels = FALSE;
+          save_transp_pixels = FALSE;
           extra--;
         }
       else if (extra > 0 && (extra_types[0] == EXTRASAMPLE_UNASSALPHA))
         {
           alpha = TRUE;
-          tsvals.save_transp_pixels = TRUE;
+          save_transp_pixels = TRUE;
           extra--;
         }
       else if (extra > 0 && (extra_types[0] == EXTRASAMPLE_UNSPECIFIED))
@@ -801,11 +786,11 @@ load_image (GFile        *file,
             {
             case GIMP_TIFF_LOAD_ASSOCALPHA:
               alpha = TRUE;
-              tsvals.save_transp_pixels = FALSE;
+              save_transp_pixels = FALSE;
               break;
             case GIMP_TIFF_LOAD_UNASSALPHA:
               alpha = TRUE;
-              tsvals.save_transp_pixels = TRUE;
+              save_transp_pixels = TRUE;
               break;
             default: /* GIMP_TIFF_LOAD_CHANNEL */
               alpha = FALSE;
@@ -827,11 +812,11 @@ load_image (GFile        *file,
                 {
                 case GIMP_TIFF_LOAD_ASSOCALPHA:
                   alpha = TRUE;
-                  tsvals.save_transp_pixels = FALSE;
+                  save_transp_pixels = FALSE;
                   break;
                 case GIMP_TIFF_LOAD_UNASSALPHA:
                   alpha = TRUE;
-                  tsvals.save_transp_pixels = TRUE;
+                  save_transp_pixels = TRUE;
                   break;
                 default: /* GIMP_TIFF_LOAD_CHANNEL */
                   alpha = FALSE;
@@ -902,7 +887,7 @@ load_image (GFile        *file,
             }
           else if (alpha)
             {
-              if (tsvals.save_transp_pixels)
+              if (save_transp_pixels)
                 {
                   if (profile_linear)
                     {
@@ -966,7 +951,7 @@ load_image (GFile        *file,
 
           if (alpha)
             {
-              if (tsvals.save_transp_pixels)
+              if (save_transp_pixels)
                 {
                   if (profile_linear)
                     {
@@ -1042,12 +1027,12 @@ load_image (GFile        *file,
            * attached profile, so we'll check for it and set up
            * space accordingly
            */
+          is_cmyk = TRUE;
           if (profile && gimp_color_profile_is_cmyk (profile))
             {
               space = gimp_color_profile_get_space (profile,
                                                     GIMP_COLOR_RENDERING_INTENT_RELATIVE_COLORIMETRIC,
                                                     error);
-              g_clear_object (&profile);
             }
           else
             {
@@ -1115,7 +1100,7 @@ load_image (GFile        *file,
               }
           }
 
-        save_vals.compression = compression;
+        gimp_compression = tiff_compression_to_gimp_compression (compression);
       }
 
       if (worst_case)
@@ -1162,40 +1147,25 @@ load_image (GFile        *file,
           *image = gimp_image_new_with_precision (cols, rows, image_type,
                                                   image_precision);
 
-          if (*image < 1)
+          if (! *image)
             {
               TIFFClose (tif);
               g_message (_("Could not create a new image: %s"),
-                         gimp_get_pdb_error ());
+                         gimp_pdb_get_last_error (gimp_get_pdb ()));
               return GIMP_PDB_EXECUTION_ERROR;
             }
 
           gimp_image_undo_disable (*image);
 
           if (pages.target == GIMP_PAGE_SELECTOR_TARGET_IMAGES)
-            {
-              gchar *fname = g_strdup_printf ("%s-%d", g_file_get_uri (file),
-                                              ilayer);
+            images_list = g_list_prepend (images_list, *image);
+        }
 
-              gimp_image_set_filename (*image, fname);
-              g_free (fname);
-
-              images_list = g_list_prepend (images_list,
-                                            GINT_TO_POINTER (*image));
-            }
-          else if (pages.o_pages != pages.n_pages)
-            {
-              gchar *fname = g_strdup_printf (_("%s-%d-of-%d-pages"),
-                                              g_file_get_uri (file),
-                                              pages.n_pages, pages.o_pages);
-
-              gimp_image_set_filename (*image, fname);
-              g_free (fname);
-            }
-          else
-            {
-              gimp_image_set_filename (*image, g_file_get_uri (file));
-            }
+      /* attach CMYK profile to GimpImage if applicable */
+      if (profile && gimp_color_profile_is_cmyk (profile))
+        {
+          gimp_image_set_simulation_profile (*image, profile);
+          g_clear_object (&profile);
         }
 
       /* attach non-CMYK color profile */
@@ -1209,14 +1179,33 @@ load_image (GFile        *file,
 
       /* attach parasites */
       {
-        GimpParasite *parasite;
-        const gchar  *img_desc;
+        GString          *string;
+        GimpConfigWriter *writer;
+        GimpParasite     *parasite;
+        const gchar      *img_desc;
 
-        parasite = gimp_parasite_new ("tiff-save-options", 0,
-                                      sizeof (save_vals), &save_vals);
+        /* construct the save parasite manually instead of simply
+         * creating and saving a save config object, because we want
+         * it to contain only some properties
+         */
+
+        string = g_string_new (NULL);
+        writer = gimp_config_writer_new_from_string (string);
+
+        gimp_config_writer_open (writer, "compression");
+        gimp_config_writer_printf (writer, "%d", gimp_compression);
+        gimp_config_writer_close (writer);
+
+        gimp_config_writer_finish (writer, NULL, NULL);
+
+        parasite = gimp_parasite_new ("GimpProcedureConfig-file-tiff-save-last",
+                                      GIMP_PARASITE_PERSISTENT,
+                                      string->len + 1, string->str);
         gimp_image_attach_parasite (*image, parasite);
         gimp_parasite_free (parasite);
 
+        g_string_free (string, TRUE);
+
         /* Attach a parasite containing the image description.
          * Pretend to be a gimp comment so other plugins will use this
          * description as an image comment where appropriate.
@@ -1232,11 +1221,12 @@ load_image (GFile        *file,
           }
       }
 
+
       /* Attach GeoTIFF Tags as Parasite, If available */
       {
         GimpParasite *parasite    = NULL;
         void         *geotag_data = NULL;
-        uint32        count       = 0;
+        uint32_t      count       = 0;
 
         if (TIFFGetField (tif, GEOTIFF_MODELPIXELSCALE, &count, &geotag_data))
           {
@@ -1301,8 +1291,8 @@ load_image (GFile        *file,
 
       /* any resolution info in the file? */
       {
-        gfloat   xres = 72.0;
-        gfloat   yres = 72.0;
+        gdouble   xres = 72.0;
+        gdouble   yres = 72.0;
         gushort  read_unit;
         GimpUnit unit = GIMP_UNIT_PIXEL; /* invalid unit */
 
@@ -1505,12 +1495,6 @@ load_image (GFile        *file,
           gimp_image_set_colormap (*image, cmap, (1 << bps));
         }
 
-      if (pages.target != GIMP_PAGE_SELECTOR_TARGET_IMAGES)
-        load_paths (tif, *image, cols, rows,
-                    layer_offset_x_pixel, layer_offset_y_pixel);
-      else
-        load_paths (tif, *image, cols, rows, 0, 0);
-
       if (extra > 99)
         {
           /* Validate number of channels to the same maximum as we use for
@@ -1558,37 +1542,50 @@ load_image (GFile        *file,
           /* can't create the palette format here, need to get it from
            * an existing layer
            */
-          base_format = gimp_drawable_get_format (layer);
+          base_format = gimp_drawable_get_format (GIMP_DRAWABLE (layer));
         }
       else if (! space)
         {
           base_format =
             babl_format_with_space (babl_format_get_encoding (base_format),
-                                    gimp_drawable_get_format (layer));
+                                    gimp_drawable_get_format (GIMP_DRAWABLE (layer)));
         }
 
-      channel[0].ID     = layer;
-      channel[0].buffer = gimp_drawable_get_buffer (layer);
-      channel[0].format = base_format;
+      channel[0].drawable = GIMP_DRAWABLE (layer);
+      channel[0].buffer   = gimp_drawable_get_buffer (GIMP_DRAWABLE (layer));
+      channel[0].format   = base_format;
 
       if (extra > 0 && ! worst_case)
         {
           /* Add extra channels as appropriate */
           for (i = 1; i <= extra; i++)
             {
-              GimpRGB color;
+              GeglColor *color = gegl_color_new ("black");
 
-              gimp_rgb_set (&color, 0.0, 0.0, 0.0);
+              channel[i].drawable = GIMP_DRAWABLE (gimp_channel_new (*image, _("TIFF Channel"),
+                                                                     cols, rows, 100.0, color));
+              g_object_unref (color);
+              gimp_image_insert_channel (*image, GIMP_CHANNEL (channel[i].drawable), NULL, 0);
+              channel[i].buffer = gimp_drawable_get_buffer (channel[i].drawable);
 
-              channel[i].ID = gimp_channel_new (*image, _("TIFF Channel"),
-                                                cols, rows,
-                                                100.0, &color);
-              gimp_image_insert_channel (*image, channel[i].ID, -1, 0);
-              channel[i].buffer = gimp_drawable_get_buffer (channel[i].ID);
-              channel[i].format = babl_format_new (babl_model ("Y'"),
-                                                   type,
-                                                   babl_component ("Y'"),
-                                                   NULL);
+              /* Unlike color channels, we don't care about the source
+               * TRC for extra channels. We just want to import them
+               * as-is without any value conversion. Since extra
+               * channels are always linear in GIMP, we consider TIFF
+               * extra channels with unspecified data to be linear too.
+               * Only exception are 8-bit non-linear images whose
+               * channel are Y' for legacy/compatibility reasons.
+               */
+              if (image_precision == GIMP_PRECISION_U8_NON_LINEAR)
+                channel[i].format = babl_format_new (babl_model ("Y'"),
+                                                     type,
+                                                     babl_component ("Y'"),
+                                                     NULL);
+              else
+                channel[i].format = babl_format_new (babl_model ("Y"),
+                                                     type,
+                                                     babl_component ("Y"),
+                                                     NULL);
             }
         }
 
@@ -1638,13 +1635,13 @@ load_image (GFile        *file,
             }
 
           if (flip_horizontal)
-            gimp_item_transform_flip_simple (layer,
+            gimp_item_transform_flip_simple (GIMP_ITEM (layer),
                                              GIMP_ORIENTATION_HORIZONTAL,
                                              TRUE /* auto_center */,
                                              -1.0 /* axis */);
 
           if (flip_vertical)
-            gimp_item_transform_flip_simple (layer,
+            gimp_item_transform_flip_simple (GIMP_ITEM (layer),
                                              GIMP_ORIENTATION_VERTICAL,
                                              TRUE /* auto_center */,
                                              -1.0 /* axis */);
@@ -1682,7 +1679,7 @@ load_image (GFile        *file,
             }
         }
 
-      gimp_image_insert_layer (*image, layer, -1, -1);
+      gimp_image_insert_layer (*image, layer, NULL, -1);
 
       if (pages.target == GIMP_PAGE_SELECTOR_TARGET_IMAGES)
         {
@@ -1700,14 +1697,14 @@ load_image (GFile        *file,
 
       if (list)
         {
-          *image = GPOINTER_TO_INT (list->data);
+          *image = list->data;
 
           list = g_list_next (list);
         }
 
       for (; list; list = g_list_next (list))
         {
-          gimp_display_new (GPOINTER_TO_INT (list->data));
+          gimp_display_new (list->data);
         }
 
       g_list_free (images_list);
@@ -1740,6 +1737,89 @@ load_image (GFile        *file,
       gimp_image_undo_enable (*image);
     }
 
+  /* Load Photoshop layer metadata */
+  if (TIFFGetField (tif, TIFFTAG_PHOTOSHOP, &photoshop_len, &photoshop_data))
+    {
+      FILE           *fp;
+      GFile          *temp_file   = NULL;
+      GimpProcedure  *procedure;
+      GimpValueArray *return_vals = NULL;
+
+      temp_file = gimp_temp_file ("tmp");
+      fp = g_fopen (g_file_peek_path (temp_file), "wb");
+
+      if (! fp)
+        {
+          g_message (_("Error trying to open temporary %s file '%s' "
+                       "for tiff metadata loading: %s"),
+                     "tmp", gimp_file_get_utf8_name (temp_file),
+                     g_strerror (errno));
+        }
+
+      fwrite (photoshop_data, sizeof (guchar), photoshop_len, fp);
+      fclose (fp);
+
+      procedure   = gimp_pdb_lookup_procedure (gimp_get_pdb (),
+                                               "file-psd-load-metadata");
+      return_vals = gimp_procedure_run (procedure,
+                                        "run-mode",      GIMP_RUN_NONINTERACTIVE,
+                                        "file",          temp_file,
+                                        "size",          photoshop_len,
+                                        "image",         *image,
+                                        "metadata-type", FALSE,
+                                        NULL);
+
+      g_file_delete (temp_file, NULL, NULL);
+      g_object_unref (temp_file);
+      gimp_value_array_unref (return_vals);
+
+      *ps_metadata_loaded = TRUE;
+    }
+
+  if (TIFFGetField (tif, TIFFTAG_IMAGESOURCEDATA, &photoshop_len, &photoshop_data))
+    {
+      FILE           *fp;
+      GFile          *temp_file   = NULL;
+      GimpProcedure  *procedure;
+      GimpValueArray *return_vals = NULL;
+
+      /* Photoshop metadata starts with 'Adobe Photoshop Document Data Block'
+       * so we need to skip past that for the data. */
+      photoshop_data += 36;
+      photoshop_len  -= 36;
+
+      temp_file = gimp_temp_file ("tmp");
+      fp = g_fopen (g_file_peek_path (temp_file), "wb");
+
+      if (! fp)
+        {
+          g_message (_("Error trying to open temporary %s file '%s' "
+                       "for tiff metadata loading: %s"),
+                     "tmp", gimp_file_get_utf8_name (temp_file),
+                     g_strerror (errno));
+        }
+
+      fwrite (photoshop_data, sizeof (guchar), photoshop_len, fp);
+      fclose (fp);
+
+      procedure   = gimp_pdb_lookup_procedure (gimp_get_pdb (),
+                                               "file-psd-load-metadata");
+      return_vals = gimp_procedure_run (procedure,
+                                        "run-mode",      run_mode,
+                                        "file",          temp_file,
+                                        "size",          photoshop_len,
+                                        "image",         *image,
+                                        "metadata-type", TRUE,
+                                        "cmyk",          is_cmyk,
+                                        NULL);
+
+      g_file_delete (temp_file, NULL, NULL);
+      g_object_unref (temp_file);
+      gimp_value_array_unref (return_vals);
+
+      *ps_metadata_loaded = TRUE;
+    }
+
   g_free (pages.pages);
   TIFFClose (tif);
 
@@ -1756,8 +1836,8 @@ load_profile (TIFF *tif)
    * libtiff version that can handle ICC profiles. Otherwise just
    * return a NULL profile.
    */
-  uint32  profile_size;
-  guchar *icc_profile;
+  uint32_t  profile_size;
+  guchar   *icc_profile;
 
   /* set the ICC profile - if found in the TIFF */
   if (TIFFGetField (tif, TIFFTAG_ICCPROFILE, &profile_size, &icc_profile))
@@ -1785,7 +1865,7 @@ load_rgba (TIFF        *tif,
   TIFFGetField (tif, TIFFTAG_IMAGEWIDTH,  &image_width);
   TIFFGetField (tif, TIFFTAG_IMAGELENGTH, &image_height);
 
-  buffer = g_new (uint32, image_width * image_height);
+  buffer = g_new (uint32_t, image_width * image_height);
 
   if (! TIFFReadRGBAImage (tif, image_width, image_height, buffer, 0))
     {
@@ -1821,203 +1901,6 @@ load_rgba (TIFF        *tif,
   g_free (buffer);
 }
 
-static void
-load_paths (TIFF *tif,
-            gint  image,
-            gint  width,
-            gint  height,
-            gint  offset_x,
-            gint  offset_y)
-{
-  gsize  n_bytes;
-  gchar *bytes;
-  gint   path_index;
-  gsize  pos;
-
-  if (! TIFFGetField (tif, TIFFTAG_PHOTOSHOP, &n_bytes, &bytes))
-    return;
-
-  path_index = 0;
-  pos        = 0;
-
-  while (pos < n_bytes)
-    {
-      guint16  id;
-      gsize    len;
-      gchar   *name;
-      guint32 *val32;
-      guint16 *val16;
-
-      if (n_bytes-pos < 7 ||
-          strncmp (bytes + pos, "8BIM", 4) != 0)
-        break;
-
-      pos += 4;
-
-      val16 = (guint16 *) (bytes + pos);
-      id = GUINT16_FROM_BE (*val16);
-      pos += 2;
-
-      /* g_printerr ("id: %x\n", id); */
-      len = (guchar) bytes[pos];
-
-      if (n_bytes - pos < len + 1)
-        break;   /* block not big enough */
-
-      /* do we have the UTF-marker? is it valid UTF-8?
-       * if so, we assume an utf-8 encoded name, otherwise we
-       * assume iso8859-1
-       */
-      name = bytes + pos + 1;
-      if (len >= 3 &&
-          name[0] == '\xEF' && name[1] == '\xBB' && name[2] == '\xBF' &&
-          g_utf8_validate (name, len, NULL))
-        {
-          name = g_strndup (name + 3, len - 3);
-        }
-      else
-        {
-          name = g_convert (name, len, "utf-8", "iso8859-1", NULL, NULL, NULL);
-        }
-
-      if (! name)
-        name = g_strdup ("(imported path)");
-
-      pos += len + 1;
-
-      if (pos % 2)  /* padding */
-        pos++;
-
-      if (n_bytes - pos < 4)
-        break;   /* block not big enough */
-
-      val32 = (guint32 *) (bytes + pos);
-      len = GUINT32_FROM_BE (*val32);
-      pos += 4;
-
-      if (n_bytes - pos < len)
-        break;   /* block not big enough */
-
-      if (id >= 2000 && id <= 2998)
-        {
-          /* path information */
-          guint16   type;
-          gint      rec = pos;
-          gint32    vectors;
-          gdouble  *points          = NULL;
-          gint      expected_points = 0;
-          gint      pointcount      = 0;
-          gboolean  closed          = FALSE;
-
-          vectors = gimp_vectors_new (image, name);
-          gimp_image_insert_vectors (image, vectors, -1, path_index);
-          path_index++;
-
-          while (rec < pos + len)
-            {
-              /* path records */
-              val16 = (guint16 *) (bytes + rec);
-              type = GUINT16_FROM_BE (*val16);
-
-              switch (type)
-                {
-                case 0:  /* new closed subpath */
-                case 3:  /* new open subpath */
-                  val16 = (guint16 *) (bytes + rec + 2);
-                  expected_points = GUINT16_FROM_BE (*val16);
-                  pointcount = 0;
-                  closed = (type == 0);
-
-                  if (n_bytes - rec < (expected_points + 1) * 26)
-                    {
-                      g_printerr ("not enough point records\n");
-                      rec = pos + len;
-                      continue;
-                    }
-
-                  if (points)
-                    g_free (points);
-                  points = g_new (gdouble, expected_points * 6);
-                  break;
-
-                case 1:  /* closed subpath bezier knot, linked */
-                case 2:  /* closed subpath bezier knot, unlinked */
-                case 4:  /* open subpath bezier knot, linked */
-                case 5:  /* open subpath bezier knot, unlinked */
-                  /* since we already know if the subpath is open
-                   * or closed and since we don't differentiate between
-                   * linked and unlinked, just treat all the same...  */
-
-                  if (pointcount < expected_points)
-                    {
-                      gint j;
-
-                      for (j = 0; j < 6; j++)
-                        {
-                          gdouble f;
-                          guint32 coord;
-
-                          const gint size = j % 2 ? width : height;
-                          const gint offset = j % 2 ? offset_x : offset_y;
-
-                          val32 = (guint32 *) (bytes + rec + 2 + j * 4);
-                          coord = GUINT32_FROM_BE (*val32);
-
-                          f = (double) ((gchar) ((coord >> 24) & 0xFF)) +
-                              (double) (coord & 0x00FFFFFF) /
-                              (double) 0xFFFFFF;
-
-                          /* coords are stored with vertical component
-                           * first, gimp expects the horizontal
-                           * component first. Sigh.
-                           */
-                          points[pointcount * 6 + (j ^ 1)] = f * size + offset;
-                        }
-
-                      pointcount++;
-
-                      if (pointcount == expected_points)
-                        {
-                          gimp_vectors_stroke_new_from_points (vectors,
-                                                               GIMP_VECTORS_STROKE_TYPE_BEZIER,
-                                                               pointcount * 6,
-                                                               points,
-                                                               closed);
-                        }
-                    }
-                  else
-                    {
-                      g_printerr ("Oops - unexpected point record\n");
-                    }
-
-                  break;
-
-                case 6:  /* path fill rule record */
-                case 7:  /* clipboard record (?) */
-                case 8:  /* initial fill rule record (?) */
-                  /* we cannot use this information */
-
-                default:
-                  break;
-                }
-
-              rec += 26;
-            }
-
-          if (points)
-            g_free (points);
-        }
-
-      pos += len;
-
-      if (pos % 2)  /* padding */
-        pos++;
-
-      g_free (name);
-    }
-}
-
-
 static void
 load_contiguous (TIFF         *tif,
                  ChannelData  *channel,
@@ -2651,11 +2534,11 @@ load_dialog (const gchar       *help_id,
   GtkWidget  *dialog;
   GtkWidget  *vbox;
   GtkWidget  *show_reduced = NULL;
-  GtkWidget  *crop_option = NULL;
-  GtkWidget  *extra_radio = NULL;
+  GtkWidget  *crop_option  = NULL;
+  GtkWidget  *extra_radio  = NULL;
   gboolean    run;
 
-  pages->selector         = NULL;
+  pages->selector = NULL;
 
   dialog = gimp_dialog_new (_("Import from TIFF"), PLUG_IN_ROLE,
                             NULL, 0,
@@ -2666,7 +2549,7 @@ load_dialog (const gchar       *help_id,
 
                             NULL);
 
-  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
+  gimp_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
                                            GTK_RESPONSE_OK,
                                            GTK_RESPONSE_CANCEL,
                                            -1);
@@ -2731,7 +2614,7 @@ load_dialog (const gchar       *help_id,
 
       extra_radio = gimp_int_radio_group_new (TRUE, _("Process extra channel as:"),
                                               (GCallback) gimp_radio_button_update,
-                                              default_extra, GIMP_TIFF_LOAD_UNASSALPHA,
+                                              default_extra, NULL, GIMP_TIFF_LOAD_UNASSALPHA,
                                               _("_Non-premultiplied alpha"), GIMP_TIFF_LOAD_UNASSALPHA, NULL,
                                               _("Pre_multiplied alpha"),     GIMP_TIFF_LOAD_ASSOCALPHA, NULL,
                                               _("Channe_l"),                 GIMP_TIFF_LOAD_CHANNEL,    NULL,
@@ -2781,8 +2664,8 @@ tiff_dialog_show_reduced (GtkWidget *toggle,
 {
   gint selectable_pages;
   gint i, j;
-  TiffSelectedPages *pages = (TiffSelectedPages *) data;
 
+  TiffSelectedPages *pages = (TiffSelectedPages *) data;
   pages->show_reduced = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggle));
 
   /* Clear current pages from selection */
